@@ -1,5 +1,5 @@
 if (require(tinytest, quietly = TRUE)) {
-  home <- identical(Sys.info()["nodename"], "Abbott-2.local")
+  home <- Sys.info()["nodename"] == "BryanHs-MacBook-Pro.local"
   tinytest::test_package("ChemoSpec", verbose = TRUE, at_home = home)
 }
 
